package com.abernard.zest;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.part.ViewPart;
import org.eclipse.zest.core.widgets.Graph;
import org.eclipse.zest.core.widgets.GraphConnection;
import org.eclipse.zest.core.widgets.GraphNode;
import org.eclipse.zest.layouts.LayoutStyles;
import org.eclipse.zest.layouts.algorithms.SpringLayoutAlgorithm;

/**
 * Cette vue contient un graphe construit programmatiquement, en construisant 
 * 'a la main' les noeuds et les branches.
 * 
 * @author A. Bernard
 *
 */
public class BasicGraphView extends ViewPart {

	/**
	 * le graphe
	 */
	private Graph graph;

	@Override
	public void createPartControl(Composite parent) {
		//Le Graph contient tous les autres objets
		graph = new Graph(parent, SWT.NONE);
		
		// Les villes sont les noeuds du graphe
		GraphNode paris = new GraphNode(graph, SWT.NONE, "Paris");
		GraphNode bordeaux = new GraphNode(graph, SWT.NONE, "Bordeaux");
		GraphNode poitiers = new GraphNode(graph, SWT.NONE, "Poitiers");
		GraphNode toulouse = new GraphNode(graph, SWT.NONE, "Toulouse");
		
		// Construction des branches du graphe.
		//Chaque branche affiche la distance kilometrique entre deux villes
		GraphConnection parisToulouse = new GraphConnection(graph, SWT.NONE, 
				toulouse, paris);
		parisToulouse.setText("678km");
		
		GraphConnection parisPoitiers = new GraphConnection(graph, SWT.NONE, 
				paris, poitiers);
		parisPoitiers.setText("338km");

		GraphConnection poitiersBordeaux = new GraphConnection(graph, SWT.NONE, 
				bordeaux, poitiers);
		poitiersBordeaux.setText("235km");

		GraphConnection bordeauxToulouse = new GraphConnection(graph, SWT.NONE,
				toulouse, bordeaux);
		bordeauxToulouse.setText("244km");

		//Definition de l'algorithme de rendu du graphe
		//Ces layouts seront decrits dans un prochain cours
		graph.setLayoutAlgorithm(new SpringLayoutAlgorithm(
				LayoutStyles.NO_LAYOUT_NODE_RESIZING), true);
	}

	@Override
	public void setFocus() {
		// 
	}
}