package com.abernard.zest;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.part.ViewPart;
import org.eclipse.zest.core.viewers.GraphViewer;
import org.eclipse.zest.layouts.LayoutStyles;
import org.eclipse.zest.layouts.algorithms.SpringLayoutAlgorithm;

import com.abernard.zest.model.Model;
import com.abernard.zest.viewer.LinkContentProvider;
import com.abernard.zest.viewer.LinkLabelProvider;

/**
 * Cette vue affiche un graphe construit a partir d'un modele base sur les 
 * branches du graphe (dans notre cas les routes).
 * 
 * @author A. Bernard
 */
public class LinkGraphView extends ViewPart {
	
	/**
	 * le graphe
	 */
	private GraphViewer viewer;

	@Override
	public void createPartControl(Composite parent) {
		viewer = new GraphViewer(parent, SWT.NONE);
		//Traitement du contenu
		viewer.setContentProvider(new LinkContentProvider());
		//Traitement de l'affichage
		viewer.setLabelProvider(new LinkLabelProvider());
		
		//Donnees d'entree du graphe
		//Comme pour les autres viewers JFace, la methode setInput doit etre 
		// appelee APRES la definition des ContentProvider et LabelProvider.
		viewer.setInput(Model.INSTANCE.getRoutes());
		
		//Definition du layout
		viewer.setLayoutAlgorithm(new SpringLayoutAlgorithm(LayoutStyles.NO_LAYOUT_NODE_RESIZING));
		viewer.applyLayout();

	}

	@Override
	public void setFocus() {
		// 
	}
}
