package com.abernard.zest.model;

import java.util.ArrayList;
import java.util.List;

/**
 * Modele de notre graphe. Il contient toutes les villes et toutes les routes, 
 * et permet d'acceder soit a la liste de toutes les villes, soit a la liste de
 *  toutes les routes
 *  
 * @author A. Bernard
 */
public enum Model {
	
	/**
	 * l'instance unique de notre modele
	 */
	INSTANCE;
	
	/**
	 * toutes les villes du graphe
	 */
	private List<Ville> villes;
	
	/**
	 * toutes les routes du graphe
	 */
	private List<Route> routes;
	
	/**
	 * Constructeur. Initialise le modele.
	 */
	private Model() {
		villes = new ArrayList<Ville>();
		routes = new ArrayList<Route>();
		
		//Creation de toutes les villes du graphe
		Ville paris = new Ville("Paris");
		villes.add(paris);
		Ville toulouse = new Ville("Toulouse");
		villes.add(toulouse);
		Ville bordeaux = new Ville("Bordeaux");
		villes.add(bordeaux);
		Ville poitiers = new Ville("Poitiers");
		villes.add(poitiers);
		Ville metz = new Ville("Metz");
		villes.add(metz);
		
		//Creation de toutes les routes
		Route r1 = new Route(paris, toulouse, 678);
		routes.add(r1);
		paris.addConnexion(toulouse);
		
		r1 = new Route(paris, poitiers, 338);
		routes.add(r1);
		poitiers.addConnexion(paris);
		
		r1 = new Route(poitiers, bordeaux, 235);
		routes.add(r1);
		bordeaux.addConnexion(poitiers);
		
		r1 = new Route(bordeaux, toulouse, 244);
		routes.add(r1);
		toulouse.addConnexion(bordeaux);
		
		r1 = new Route(paris, metz, 333);
		routes.add(r1);
		paris.addConnexion(metz);
	}
	
	/**
	 * Donne la liste de toutes les villes
	 * @return la liste des villes
	 */
	public List<Ville> getVilles() {
		return villes;
	}

	/**
	 * Donne la liste de toutes les routes
	 * @return la liste des routes
	 */
	public List<Route> getRoutes() {
		return routes;
	}
}
